@@ -124,7 +124,7 @@ void Variable::setInScope(bool v)
 {
     m_inScope = v;
     for (int i=0; i < childCount(); ++i) {
-        if (Variable *var = qobject_cast<Variable*>(child(i))) {
+        if (auto *var = qobject_cast<Variable*>(child(i))) {
             var->setInScope(v);
         }
     }
@@ -302,7 +302,7 @@ QVariant Watches::data(int column, int role) const
 #if 0
     if (column == 0 && role == Qt::FontRole)
     {
-        /* FIXME: is creating font again and agian efficient? */
+        /* FIXME: is creating font again and again efficient? */
         QFont f = font();
         f.setBold(true);
         return f;
@@ -315,7 +315,7 @@ void Watches::reinstall()
 {
     for (int i = 0; i < childItems.size(); ++i)
     {
-        Variable* v = static_cast<Variable*>(child(i));
+        auto* v = static_cast<Variable*>(child(i));
         v->attachMaybe();
     }
 }
@@ -332,11 +332,11 @@ QList<Variable*> Locals::updateLocals(const QStringList& locals)
     for (int i = 0; i < childItems.size(); i++)
     {
         Q_ASSERT(qobject_cast<KDevelop::Variable*>(child(i)));
-        Variable* var= static_cast<KDevelop::Variable*>(child(i));
+        auto* var= static_cast<KDevelop::Variable*>(child(i));
         existing << var->expression();
     }
 
-    foreach (const QString& var, locals) {
+    for (const QString& var : locals) {
         current << var;
         // If we currently don't display this local var, add it.
         if( !existing.contains( var ) ) {
@@ -352,7 +352,7 @@ QList<Variable*> Locals::updateLocals(const QStringList& locals)
     }
 
     for (int i = 0; i < childItems.size(); ++i) {
-        KDevelop::Variable* v = static_cast<KDevelop::Variable*>(child(i));
+        auto* v = static_cast<KDevelop::Variable*>(child(i));
         if (!current.contains(v->expression())) {
             removeChild(i);
             --i;
@@ -371,7 +371,7 @@ QList<Variable*> Locals::updateLocals(const QStringList& locals)
 
     QList<Variable*> ret;
     ret.reserve(childItems.size());
-    foreach (TreeItem *i, childItems) {
+    for (TreeItem* i : qAsConst(childItems)) {
         Q_ASSERT(qobject_cast<Variable*>(i));
         ret << static_cast<Variable*>(i);
     }
@@ -398,11 +398,12 @@ VariablesRoot::VariablesRoot(TreeModel* model)
 
 Locals* VariablesRoot::locals(const QString& name)
 {
-    if (!m_locals.contains(name)) {
-        m_locals[name] = new Locals(model(), this, name);
-        appendChild(m_locals[name]);
+    auto localsIt = m_locals.find(name);
+    if (localsIt == m_locals.end()) {
+        localsIt = m_locals.insert(name, new Locals(model(), this, name));
+        appendChild(*localsIt);
     }
-    return m_locals[name];
+    return *localsIt;
 }
 
 QHash<QString, Locals*> VariablesRoot::allLocals() const
@@ -413,7 +414,7 @@ QHash<QString, Locals*> VariablesRoot::allLocals() const
 void VariablesRoot::resetChanged()
 {
     m_watches->resetChanged();
-    foreach (Locals *l, m_locals) {
+    for (Locals* l : qAsConst(m_locals)) {
         l->resetChanged();
     }
 }
@@ -483,8 +484,10 @@ void VariableCollection::textDocumentCreated(IDocument* doc)
        &KTextEditor::Document::viewCreated,
        this, &VariableCollection::viewCreated );
 
-  foreach( KTextEditor::View* view, doc->textDocument()->views() )
+  const auto views = doc->textDocument()->views();
+  for (KTextEditor::View* view : views) {
     viewCreated( doc->textDocument(), view );
+  }
 }
 
 void VariableCollection::viewCreated(KTextEditor::Document* doc,
@@ -492,7 +495,7 @@ void VariableCollection::viewCreated(KTextEditor::Document* doc,
 {
     Q_UNUSED(doc);
     using namespace KTextEditor;
-    TextHintInterface *iface = dynamic_cast<TextHintInterface*>(view);
+    auto* iface = qobject_cast<TextHintInterface*>(view);
     if( !iface )
         return;
 
