@@ -15,7 +15,7 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
-*/
+ */
 
 #include "renameaction.h"
 
@@ -32,20 +32,21 @@
 
 using namespace KDevelop;
 
-QVector<RevisionedFileRanges> RevisionedFileRanges::convert(const QMap<IndexedString, QVector<RangeInRevision> >& uses)
+QVector<RevisionedFileRanges> RevisionedFileRanges::convert(const QMap<IndexedString, QVector<RangeInRevision>>& uses)
 {
     QVector<RevisionedFileRanges> ret(uses.size());
     auto insertIt = ret.begin();
-    for (auto it = uses.constBegin(); it != uses.constEnd(); ++it, ++insertIt)
-    {
+    for (auto it = uses.constBegin(); it != uses.constEnd(); ++it, ++insertIt) {
         insertIt->file = it.key();
         insertIt->ranges = it.value();
 
-        DocumentChangeTracker* tracker = ICore::self()->languageController()->backgroundParser()->trackerForUrl(it.key());
+        DocumentChangeTracker* tracker =
+            ICore::self()->languageController()->backgroundParser()->trackerForUrl(it.key());
         if (tracker) {
             insertIt->revision = tracker->revisionAtLastReset();
         }
     }
+
     return ret;
 }
 
@@ -59,8 +60,10 @@ public:
 
 RenameAction::RenameAction(const Identifier& oldDeclarationName, const QString& newDeclarationName,
                            const QVector<RevisionedFileRanges>& oldDeclarationUses)
-    : d(new RenameActionPrivate)
+    : d_ptr(new RenameActionPrivate)
 {
+    Q_D(RenameAction);
+
     d->m_oldDeclarationName = oldDeclarationName;
     d->m_newDeclarationName = newDeclarationName.trimmed();
     d->m_oldDeclarationUses = oldDeclarationUses;
@@ -72,25 +75,33 @@ RenameAction::~RenameAction()
 
 QString RenameAction::description() const
 {
+    Q_D(const RenameAction);
+
     return i18n("Rename \"%1\" to \"%2\"", d->m_oldDeclarationName.toString(), d->m_newDeclarationName);
 }
 
 QString RenameAction::newDeclarationName() const
 {
+    Q_D(const RenameAction);
+
     return d->m_newDeclarationName;
 }
 
 QString RenameAction::oldDeclarationName() const
 {
+    Q_D(const RenameAction);
+
     return d->m_oldDeclarationName.toString();
 }
 
 void RenameAction::execute()
 {
+    Q_D(RenameAction);
+
     DocumentChangeSet changes;
 
-    foreach(const RevisionedFileRanges& ranges, d->m_oldDeclarationUses) {
-        foreach (const RangeInRevision range, ranges.ranges) {
+    for (const RevisionedFileRanges& ranges : qAsConst(d->m_oldDeclarationUses)) {
+        for (const RangeInRevision range : ranges.ranges) {
             KTextEditor::Range currentRange;
             if (ranges.revision && ranges.revision->valid()) {
                 currentRange = ranges.revision->transformToCurrentRevision(range);
@@ -98,8 +109,8 @@ void RenameAction::execute()
                 currentRange = range.castToSimpleRange();
             }
             DocumentChange useRename(ranges.file, currentRange,
-                                     d->m_oldDeclarationName.toString(), d->m_newDeclarationName);
-            changes.addChange( useRename );
+                d->m_oldDeclarationName.toString(), d->m_newDeclarationName);
+            changes.addChange(useRename);
             changes.setReplacementPolicy(DocumentChangeSet::WarnOnFailedChange);
         }
     }
