@@ -116,7 +116,7 @@ private Q_SLOTS:
                        m_cachedLines.begin(), &KDevelop::stripAnsiSequences);
 
         // apply filtering strategy
-        foreach(const QString& line, m_cachedLines) {
+        for (const QString& line : qAsConst(m_cachedLines)) {
             FilteredItem item = m_filter->errorInLine(line);
             if( item.type == FilteredItem::InvalidItem ) {
                 item = m_filter->actionInLine(line);
@@ -240,13 +240,13 @@ OutputModelPrivate::~OutputModelPrivate()
 
 OutputModel::OutputModel( const QUrl& builddir, QObject* parent )
 : QAbstractListModel(parent)
-, d( new OutputModelPrivate( this, builddir ) )
+, d_ptr(new OutputModelPrivate(this, builddir))
 {
 }
 
 OutputModel::OutputModel( QObject* parent )
     : QAbstractListModel(parent)
-, d( new OutputModelPrivate( this ) )
+    , d_ptr(new OutputModelPrivate(this))
 {
 }
 
@@ -254,21 +254,18 @@ OutputModel::~OutputModel() = default;
 
 QVariant OutputModel::data(const QModelIndex& idx , int role ) const
 {
+    Q_D(const OutputModel);
+
     if( d->isValidIndex(idx, rowCount()) )
     {
         switch( role )
         {
             case Qt::DisplayRole:
                 return d->m_filteredItems.at( idx.row() ).originalLine;
-                break;
             case OutputModel::OutputItemTypeRole:
                 return static_cast<int>(d->m_filteredItems.at( idx.row() ).type);
-                break;
             case Qt::FontRole:
                 return QFontDatabase::systemFont(QFontDatabase::FixedFont);
-                break;
-            default:
-                break;
         }
     }
     return QVariant();
@@ -276,6 +273,8 @@ QVariant OutputModel::data(const QModelIndex& idx , int role ) const
 
 int OutputModel::rowCount( const QModelIndex& parent ) const
 {
+    Q_D(const OutputModel);
+
     if( !parent.isValid() )
         return d->m_filteredItems.count();
     return 0;
@@ -288,6 +287,8 @@ QVariant OutputModel::headerData( int, Qt::Orientation, int ) const
 
 void OutputModel::activate( const QModelIndex& index )
 {
+    Q_D(OutputModel);
+
     if( index.model() != this || !d->isValidIndex(index, rowCount()) )
     {
         return;
@@ -318,6 +319,8 @@ void OutputModel::activate( const QModelIndex& index )
 
 QModelIndex OutputModel::firstHighlightIndex()
 {
+    Q_D(OutputModel);
+
     if( !d->m_errorItems.empty() ) {
         return index( *d->m_errorItems.begin(), 0, QModelIndex() );
     }
@@ -333,13 +336,15 @@ QModelIndex OutputModel::firstHighlightIndex()
 
 QModelIndex OutputModel::nextHighlightIndex( const QModelIndex &currentIdx )
 {
+    Q_D(OutputModel);
+
     int startrow = d->isValidIndex(currentIdx, rowCount()) ? currentIdx.row() + 1 : 0;
 
     if( !d->m_errorItems.empty() )
     {
         qCDebug(OUTPUTVIEW) << "searching next error";
         // Jump to the next error item
-        std::set< int >::const_iterator next = d->m_errorItems.lower_bound( startrow );
+        auto next = d->m_errorItems.lower_bound( startrow );
         if( next == d->m_errorItems.end() )
             next = d->m_errorItems.begin();
 
@@ -359,6 +364,8 @@ QModelIndex OutputModel::nextHighlightIndex( const QModelIndex &currentIdx )
 
 QModelIndex OutputModel::previousHighlightIndex( const QModelIndex &currentIdx )
 {
+    Q_D(OutputModel);
+
     //We have to ensure that startrow is >= rowCount - 1 to get a positive value from the % operation.
     int startrow = rowCount() + (d->isValidIndex(currentIdx, rowCount()) ? currentIdx.row() : rowCount()) - 1;
 
@@ -367,7 +374,7 @@ QModelIndex OutputModel::previousHighlightIndex( const QModelIndex &currentIdx )
         qCDebug(OUTPUTVIEW) << "searching previous error";
 
         // Jump to the previous error item
-        std::set< int >::const_iterator previous = d->m_errorItems.lower_bound( currentIdx.row() );
+        auto previous = d->m_errorItems.lower_bound( currentIdx.row() );
 
         if( previous == d->m_errorItems.begin() )
             previous = d->m_errorItems.end();
@@ -390,6 +397,8 @@ QModelIndex OutputModel::previousHighlightIndex( const QModelIndex &currentIdx )
 
 QModelIndex OutputModel::lastHighlightIndex()
 {
+    Q_D(OutputModel);
+
     if( !d->m_errorItems.empty() ) {
         return index( *d->m_errorItems.rbegin(), 0, QModelIndex() );
     }
@@ -405,6 +414,8 @@ QModelIndex OutputModel::lastHighlightIndex()
 
 void OutputModel::setFilteringStrategy(const OutputFilterStrategy& currentStrategy)
 {
+    Q_D(OutputModel);
+
     // TODO: Turn into factory, decouple from OutputModel
     IFilterStrategy* filter = nullptr;
     switch( currentStrategy )
@@ -435,12 +446,16 @@ void OutputModel::setFilteringStrategy(const OutputFilterStrategy& currentStrate
 
 void OutputModel::setFilteringStrategy(IFilterStrategy* filterStrategy)
 {
+    Q_D(OutputModel);
+
     QMetaObject::invokeMethod(d->worker, "changeFilterStrategy",
                               Q_ARG(KDevelop::IFilterStrategy*, filterStrategy));
 }
 
 void OutputModel::appendLines( const QStringList& lines )
 {
+    Q_D(OutputModel);
+
     if( lines.isEmpty() )
         return;
 
@@ -455,11 +470,15 @@ void OutputModel::appendLine( const QString& line )
 
 void OutputModel::ensureAllDone()
 {
+    Q_D(OutputModel);
+
     QMetaObject::invokeMethod(d->worker, "flushBuffers");
 }
 
 void OutputModel::clear()
 {
+    Q_D(OutputModel);
+
     ensureAllDone();
     beginResetModel();
     d->m_filteredItems.clear();
