@@ -22,8 +22,6 @@ Boston, MA 02110-1301, USA.
 #include "mainwindow.h"
 #include "mainwindow_p.h"
 
-#include "qtcompat_p.h"
-
 #include <QDBusConnection>
 #include <QDomElement>
 #include <QDragEnterEvent>
@@ -73,7 +71,7 @@ namespace {
 
 QColor defaultColor(const QPalette& palette)
 {
-    return palette.foreground().color();
+    return palette.windowText().color();
 }
 
 QColor colorForDocument(const QUrl& url, const QPalette& palette, const QColor& defaultColor)
@@ -89,6 +87,8 @@ QColor colorForDocument(const QUrl& url, const QPalette& palette, const QColor&
 
 void MainWindow::applyMainWindowSettings(const KConfigGroup& config)
 {
+    Q_D(MainWindow);
+
     if(!d->changingActiveView())
         KXmlGuiWindow::applyMainWindowSettings(config);
 }
@@ -139,7 +139,9 @@ MainWindow::MainWindow( Sublime::Controller *parent, Qt::WindowFlags flags )
     initializeCorners();
 
     setObjectName( QStringLiteral("MainWindow") );
-    d = new MainWindowPrivate(this);
+    d_ptr = new MainWindowPrivate(this);
+
+    Q_D(MainWindow);
 
     setStandardToolBarMenuEnabled( true );
     d->setupActions();
@@ -159,16 +161,20 @@ MainWindow::~ MainWindow()
         Core::self()->shutdown();
     }
 
-    delete d;
+    delete d_ptr;
 }
 
 KTextEditorIntegration::MainWindow *MainWindow::kateWrapper() const
 {
+    Q_D(const MainWindow);
+
     return d->kateWrapper();
 }
 
 void MainWindow::split(Qt::Orientation orientation)
 {
+    Q_D(MainWindow);
+
     d->split(orientation);
 }
 
@@ -195,7 +201,7 @@ QAction* MainWindow::createCustomElement(QWidget* parent, int index, const QDomE
     //instead of calling QMenuBar::addSeparator() because menubar separators are ignored
     if (element.tagName().toLower() == QLatin1String("separator")
             && element.attribute(QStringLiteral("style")) == QLatin1String("visible")) {
-        if ( QMenuBar* bar = qobject_cast<QMenuBar*>( parent ) ) {
+        if ( auto* bar = qobject_cast<QMenuBar*>( parent ) ) {
             QAction *separatorAction = new QAction(QStringLiteral("|"), this);
             bar->insertAction( before, separatorAction );
             separatorAction->setDisabled(true);
@@ -280,8 +286,9 @@ void MainWindow::configureShortcuts()
 // so we can connect to the saved() signal to propagate changes in the editor shortcuts
 
    KShortcutsDialog dlg(KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsAllowed, this);
-    foreach (KXMLGUIClient *client, Core::self()->uiControllerInternal()->mainWindows()[0]->guiFactory()->clients())
-    {
+
+    const auto firstMainWindowClientsBefore = Core::self()->uiControllerInternal()->mainWindows()[0]->guiFactory()->clients();
+    for (KXMLGUIClient* client : firstMainWindowClientsBefore) {
         if(client && !client->xmlFile().isEmpty())
             dlg.addCollection( client->actionCollection() );
     }
@@ -290,8 +297,11 @@ void MainWindow::configureShortcuts()
     dlg.configure(true);
 
     QMap<QString, QKeySequence> shortcuts;
-    foreach(KXMLGUIClient* client, Core::self()->uiControllerInternal()->mainWindows()[0]->guiFactory()->clients()) {
-        foreach(QAction* action, client->actionCollection()->actions()) {
+    // querying again just in case something changed behind our back
+    const auto firstMainWindowClientsAfter = Core::self()->uiControllerInternal()->mainWindows()[0]->guiFactory()->clients();
+    for (KXMLGUIClient* client : firstMainWindowClientsAfter) {
+        const auto actions = client->actionCollection()->actions();
+        for (QAction* action : actions) {
             if(!action->objectName().isEmpty()) {
                 shortcuts[action->objectName()] = action->shortcut();
             }
@@ -299,11 +309,14 @@ void MainWindow::configureShortcuts()
     }
 
     for(int a = 1; a < Core::self()->uiControllerInternal()->mainWindows().size(); ++a) {
-        foreach(KXMLGUIClient* client, Core::self()->uiControllerInternal()->mainWindows()[a]->guiFactory()->clients()) {
-            foreach(QAction* action, client->actionCollection()->actions()) {
+        const auto clients = Core::self()->uiControllerInternal()->mainWindows()[a]->guiFactory()->clients();
+        for (KXMLGUIClient* client : clients) {
+            const auto actions = client->actionCollection()->actions();
+            for (QAction* action : actions) {
                 qCDebug(SHELL) << "transferring setting shortcut for" << action->objectName();
-                if(shortcuts.contains(action->objectName())) {
-                    action->setShortcut(shortcuts[action->objectName()]);
+                const auto shortcutIt = shortcuts.constFind(action->objectName());
+                if (shortcutIt != shortcuts.constEnd()) {
+                    action->setShortcut(*shortcutIt);
                 }
             }
         }
@@ -317,10 +330,12 @@ void MainWindow::shortcutsChanged()
     if(!activeClient)
         return;
 
-    foreach(IDocument * doc, Core::self()->documentController()->openDocuments()) {
+    const auto documents = Core::self()->documentController()->openDocuments();
+    for (IDocument* doc : documents) {
         KTextEditor::Document *textDocument = doc->textDocument();
         if (textDocument) {
-            foreach(KTextEditor::View *client, textDocument->views()) {
+            const auto views = textDocument->views();
+            for (KTextEditor::View* client : views) {
                 if (client != activeClient) {
                     client->reloadXML();
                 }
@@ -332,6 +347,8 @@ void MainWindow::shortcutsChanged()
 
 void MainWindow::initialize()
 {
+    Q_D(MainWindow);
+
     KStandardAction::keyBindings(this, SLOT(configureShortcuts()), actionCollection());
     setupGUI( KXmlGuiWindow::ToolBar | KXmlGuiWindow::Create | KXmlGuiWindow::Save );
 
@@ -349,8 +366,10 @@ void MainWindow::initialize()
     connect(Core::self()->sourceFormatterControllerInternal(), &SourceFormatterController::hasFormattersChanged,
              d, &MainWindowPrivate::updateSourceFormatterGuiClient);
 
-    foreach(IPlugin* plugin, Core::self()->pluginController()->loadedPlugins())
+    const auto plugins = Core::self()->pluginController()->loadedPlugins();
+    for (IPlugin* plugin : plugins) {
         d->addPlugin(plugin);
+    }
 
     guiFactory()->addClient(Core::self()->sessionController());
     if (Core::self()->sourceFormatterControllerInternal()->hasFormatters()) {
@@ -408,6 +427,8 @@ bool MainWindow::queryClose()
 
 void MainWindow::documentActivated(const QPointer<KTextEditor::Document>& textDocument)
 {
+    Q_D(MainWindow);
+
     updateCaption();
 
     // update active document connection
@@ -430,7 +451,7 @@ void MainWindow::updateCaption()
             title += QLatin1String(" - [ ");
 
         Sublime::Document* doc = area()->activeView()->document();
-        Sublime::UrlDocument* urlDoc = dynamic_cast<Sublime::UrlDocument*>(doc);
+        auto* urlDoc = qobject_cast<Sublime::UrlDocument*>(doc);
         if(urlDoc)
         {
             if (urlDoc->url().isLocalFile()) {
@@ -461,7 +482,8 @@ void MainWindow::updateAllTabColors()
     const auto defaultColor = ::defaultColor(palette());
     if (UiConfig::colorizeByProject()) {
         QHash<const Sublime::View*, QColor> viewColors;
-        foreach (auto container, containers()) {
+        const auto containers = this->containers();
+        for (auto* container : containers) {
             const auto views = container->views();
             viewColors.reserve(views.size());
             viewColors.clear();
@@ -474,7 +496,8 @@ void MainWindow::updateAllTabColors()
             container->setTabColors(viewColors);
         }
     } else {
-        foreach (auto container, containers()) {
+        const auto containers = this->containers();
+        for (auto* container : containers) {
             container->resetTabColors(defaultColor);
         }
     }
@@ -486,8 +509,10 @@ void MainWindow::updateTabColor(IDocument* doc)
         return;
 
     const auto color = colorForDocument(doc->url(), palette(), defaultColor(palette()));
-    foreach (auto container, containers()) {
-        foreach (auto view, container->views()) {
+    const auto containers = this->containers();
+    for (auto* container : containers) {
+        const auto views = container->views();
+        for (auto* view : views) {
             const auto urlDoc = qobject_cast<Sublime::UrlDocument*>(view->document());
             if (urlDoc && urlDoc->url() == doc->url()) {
                 container->setTabColor(view, color);
@@ -498,37 +523,51 @@ void MainWindow::updateTabColor(IDocument* doc)
 
 void MainWindow::registerStatus(QObject* status)
 {
+    Q_D(MainWindow);
+
     d->registerStatus(status);
 }
 
 void MainWindow::initializeStatusBar()
 {
+    Q_D(MainWindow);
+
     d->setupStatusBar();
 }
 
 void MainWindow::showErrorMessage(const QString& message, int timeout)
 {
+    Q_D(MainWindow);
+
     d->showErrorMessage(message, timeout);
 }
 
 void MainWindow::tabContextMenuRequested(Sublime::View* view, QMenu* menu)
 {
+    Q_D(MainWindow);
+
     Sublime::MainWindow::tabContextMenuRequested(view, menu);
     d->tabContextMenuRequested(view, menu);
 }
 
 void MainWindow::tabToolTipRequested(Sublime::View* view, Sublime::Container* container, int tab)
 {
+    Q_D(MainWindow);
+
     d->tabToolTipRequested(view, container, tab);
 }
 
 void MainWindow::dockBarContextMenuRequested(Qt::DockWidgetArea area, const QPoint& position)
 {
+    Q_D(MainWindow);
+
     d->dockBarContextMenuRequested(area, position);
 }
 
 void MainWindow::newTabRequested()
 {
+    Q_D(MainWindow);
+
     Sublime::MainWindow::newTabRequested();
 
     d->fileNew();
