@@ -45,6 +45,7 @@ class Core;
 class Context;
 class ContextMenuExtension;
 class IPlugin;
+class ProjectControllerPrivate;
 
 class KDEVPLATFORMSHELL_EXPORT IProjectDialogProvider : public QObject
 {
@@ -113,7 +114,7 @@ public Q_SLOTS:
     void closeAllProjects() override;
     void configureProject( IProject* ) override;
 
-    void reparseProject( IProject* project, bool forceUpdate = false  ) override;
+    void reparseProject( IProject* project, bool forceUpdate = false, bool forceAll = false  ) override;
 
     void eventuallyOpenProjectFile(KIO::Job* job, const KIO::UDSEntryList& entries);
     void openProjectForUrlSlot(bool);
@@ -168,7 +169,8 @@ private:
     void initializePluginCleanup(IProject* proj);
 
 private:
-    const QScopedPointer<class ProjectControllerPrivate> d;
+    const QScopedPointer<class ProjectControllerPrivate> d_ptr;
+    Q_DECLARE_PRIVATE(ProjectController)
     friend class ProjectControllerPrivate;
 };
 
