@@ -218,11 +218,11 @@ void EnvironmentProfileModel::setVariablesFromString(const QString& plainText)
         if (pos < 0) {
             continue;
         }
-        const QString variableName = line.left(pos).trimmed();
+        const QString variableName = line.leftRef(pos).trimmed().toString();
         if (variableName.isEmpty()) {
             continue;
         }
-        const QString value = line.mid(pos+1).trimmed();
+        const QString value = line.midRef(pos+1).trimmed().toString();
         m_varsByIndex << variableName;
         variables.insert(variableName, value);
     }
