@@ -152,7 +152,7 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
 
     centralWidget = new QWidget;
     centralWidget->setObjectName(QStringLiteral("centralWidget"));
-    QVBoxLayout* layout = new QVBoxLayout(centralWidget);
+    auto* layout = new QVBoxLayout(centralWidget);
     layout->setMargin(0);
     centralWidget->setLayout(layout);
 
@@ -220,7 +220,7 @@ void MainWindowPrivate::restoreConcentrationMode()
         m_concentrateToolBar->setObjectName(QStringLiteral("concentrateToolBar"));
         m_concentrateToolBar->addAction(m_concentrationModeAction);
         m_concentrateToolBar->toggleViewAction()->setVisible(false);
-        QWidgetAction *action = new QWidgetAction(this);
+        auto *action = new QWidgetAction(this);
 
         action->setDefaultWidget(m_mainWindow->menuBar()->cornerWidget(Qt::TopRightCorner));
         m_concentrateToolBar->addAction(action);
@@ -339,7 +339,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
         {
             if (!d->m_indexSplitters.value(index->parent())) {
                 // can happen in working set code, as that adds a view to a child index first
-                // hence, recursively reconstruct the parent indizes first
+                // hence, recursively reconstruct the parent indices first
                 operator()(index->parent());
             }
             QSplitter *parent = d->m_indexSplitters.value(index->parent());
@@ -381,7 +381,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
                     d->m_mainWindow, &MainWindow::tabContextMenuRequested);
             connect(container, &Container::tabToolTipRequested,
                     d->m_mainWindow, &MainWindow::tabToolTipRequested);
-            connect(container, static_cast<void(Container::*)(QWidget*)>(&Container::requestClose),
+            connect(container, QOverload<QWidget*>::of(&Container::requestClose),
                     d, &MainWindowPrivate::widgetCloseRequest, Qt::QueuedConnection);
             connect(container, &Container::newTabRequested,
                     d->m_mainWindow, &MainWindow::newTabRequested);
@@ -395,8 +395,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
         bool hadActiveView = false;
         Sublime::View* activeView = d->activeView;
 
-        foreach (View *view, index->views())
-        {
+        for (View* view : qAsConst(index->views())) {
             QWidget *widget = view->widget(container);
 
             if (widget)
@@ -442,8 +441,7 @@ void MainWindowPrivate::reconstruct()
     {
         QSignalBlocker blocker(m_mainWindow);
         qCDebug(SUBLIME) << "RECONSTRUCT" << area << area->shownToolViews(Sublime::Left);
-        foreach (View *view, area->toolViews())
-        {
+        for (View* view : qAsConst(area->toolViews())) {
             QString id = view->document()->documentSpecifier();
             if (!id.isEmpty())
             {
@@ -463,8 +461,7 @@ void MainWindowPrivate::clearArea()
         m_leftTabbarCornerWidget->setParent(nullptr);
 
     //reparent tool view widgets to nullptr to prevent their deletion together with dockwidgets
-    foreach (View *view, area->toolViews())
-    {
+    for (View* view : qAsConst(area->toolViews())) {
         // FIXME should we really delete here??
         bool nonDestructive = true;
         idealController->removeView(view, nonDestructive);
@@ -477,8 +474,8 @@ void MainWindowPrivate::clearArea()
 
     //reparent all view widgets to 0 to prevent their deletion together with central
     //widget. this reparenting is necessary when switching areas inside the same mainwindow
-    foreach (View *view, area->views())
-    {
+    const auto views = area->views();
+    for (View* view : views) {
         if (view->hasWidget())
             view->widget()->setParent(nullptr);
     }
@@ -520,7 +517,7 @@ void MainWindowPrivate::slotDockShown(Sublime::View* /*view*/, Sublime::Position
 
     QStringList ids;
     ids.reserve(finder.views.size());
-    foreach (View *v, finder.views) {
+    for (View* v : qAsConst(finder.views)) {
         ids << v->document()->documentSpecifier();
     }
     area->setShownToolViews(pos, ids);
@@ -552,7 +549,7 @@ void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view
 
             for(int w = 0; w < splitter->count(); ++w)
             {
-                Container *container = qobject_cast<Sublime::Container*>(splitter->widget(w));
+                auto *container = qobject_cast<Sublime::Container*>(splitter->widget(w));
                 //we need to remove extra container before reconstruction
                 //first reparent widgets in container so that they are not deleted
                 if(container)
@@ -592,7 +589,7 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
     qCDebug(SUBLIME) << "splitter " << splitter << " container " << splitter->widget(0);
     qCDebug(SUBLIME) << "structure: " << index->print() << " whole structure: " << area->rootIndex()->print();
     //find the container for the view and remove the widget
-    Container *container = qobject_cast<Container*>(splitter->widget(0));
+    auto *container = qobject_cast<Container*>(splitter->widget(0));
     if (!container) {
         qCWarning(SUBLIME) << "Splitter does not have a left widget!";
         return;
@@ -685,12 +682,12 @@ void MainWindowPrivate::aboutToRemoveView(Sublime::AreaIndex *index, Sublime::Vi
                 parentSplitter->setSizes(sizes);
             }
 
-            qCDebug(SUBLIME) << "after deleation " << parent << " has "
+            qCDebug(SUBLIME) << "after deletion " << parent << " has "
                          << parentSplitter->count() << " elements";
 
 
             //find the container somewhere to activate
-            Container *containerToActivate = parentSplitter->findChild<Sublime::Container*>();
+            auto *containerToActivate = parentSplitter->findChild<Sublime::Container*>();
             //activate the current view there
             if (containerToActivate) {
                 m_mainWindow->setActiveView(containerToActivate->viewForWidget(containerToActivate->currentWidget()));
