@@ -75,20 +75,22 @@ ApplicationInfo AppWizardDialog::appInfo() const
 
 void AppWizardDialog::pageValid( QWidget* w )
 {
-    if( m_pageItems.contains(w) )
-        setValid( m_pageItems[w], true );
+    const auto pageItemId = m_pageItems.constFind(w);
+    if (pageItemId != m_pageItems.constEnd())
+        setValid(*pageItemId, true);
 }
 
 
 void AppWizardDialog::pageInValid( QWidget* w )
 {
-    if( m_pageItems.contains(w) )
-        setValid( m_pageItems[w], false );
+    const auto pageItemId =  m_pageItems.constFind(w);
+    if (pageItemId != m_pageItems.constEnd())
+        setValid(*pageItemId, false);
 }
 
 void AppWizardDialog::next()
 {
-    AppWizardPageWidget* w = qobject_cast<AppWizardPageWidget*>(currentPage()->widget());
+    auto* w = qobject_cast<AppWizardPageWidget*>(currentPage()->widget());
     if (!w || w->shouldContinue()) {
         KAssistantDialog::next();
     }
