@@ -29,6 +29,7 @@
 #include <tests/json/declarationvalidator.h>
 
 #include "testfilepaths.h"
+#include "testprovider.h"
 
 //Include all used json tests, otherwise "Test not found"
 #include <tests/json/jsondeclarationtests.h>
@@ -55,13 +56,22 @@ void TestFiles::initTestCase()
     DUChain::self()->disablePersistentStorage();
     Core::self()->languageController()->backgroundParser()->setDelay(0);
     CodeRepresentation::setDiskChangesForbidden(true);
+
+    m_provider = new TestEnvironmentProvider;
+    IDefinesAndIncludesManager::manager()->registerBackgroundProvider(m_provider);
 }
 
 void TestFiles::cleanupTestCase()
 {
+    delete m_provider;
     TestCore::shutdown();
 }
 
+void TestFiles::cleanup()
+{
+    m_provider->clear();
+}
+
 void TestFiles::testFiles_data()
 {
     QTest::addColumn<QString>("fileName");
@@ -75,6 +85,11 @@ void TestFiles::testFiles_data()
 void TestFiles::testFiles()
 {
     QFETCH(QString, fileName);
+
+    if (QTest::currentDataTag() == QLatin1String("lambdas.cpp")) {
+        m_provider->parserArguments += "-std=c++14";
+    }
+
     const IndexedString indexedFileName(fileName);
     ReferencedTopDUContext top =
         DUChain::self()->waitForUpdate(indexedFileName, TopDUContext::AllDeclarationsContextsAndUses);
@@ -88,12 +103,15 @@ void TestFiles::testFiles()
     DUChainReadLocker lock;
     DeclarationValidator validator;
     top->visit(validator);
-    QVERIFY(validator.testsPassed());
 
-    foreach(auto problem, top->problems()) {
+    const auto problems = top->problems();
+    for (auto& problem : problems) {
         qDebug() << problem;
     }
 
+    QEXPECT_FAIL("lambdas.cpp", "capture with identifier and initializer aren't visited apparently", Abort);
+    QVERIFY(validator.testsPassed());
+
     if (!QTest::currentDataTag() || strcmp("invalid.cpp", QTest::currentDataTag()) != 0) {
         QVERIFY(top->problems().isEmpty());
     }
