@@ -62,8 +62,8 @@ static KJob* createTestJob(const QString& launchModeId, const QStringList& argum
     Q_ASSERT(type && mode);
 
     ILauncher* launcher = nullptr;
-    foreach (ILauncher *l, type->launchers())
-    {
+    const auto launchers = type->launchers();
+    for (ILauncher* l : launchers) {
         //qCDebug(CMAKE) << "available launcher" << l << l->id() << l->supportedModes();
         if (l->supportedModes().contains(mode->id())) {
             launcher = l;
@@ -118,8 +118,8 @@ void CTestRunJob::start()
 
     m_job = createTestJob(QStringLiteral("execute"), arguments, workingDirectory);
 
-    if (ExecuteCompositeJob* cjob = qobject_cast<ExecuteCompositeJob*>(m_job)) {
-        OutputJob* outputJob = cjob->findChild<OutputJob*>();
+    if (auto* cjob = qobject_cast<ExecuteCompositeJob*>(m_job)) {
+        auto* outputJob = cjob->findChild<OutputJob*>();
         Q_ASSERT(outputJob);
         outputJob->setVerbosity(m_verbosity);
 
