@@ -65,14 +65,15 @@ MIDebugSession * MIFrameStackModel::session()
 
 void MIFrameStackModel::fetchThreads()
 {
-    session()->addCommand(ThreadInfo, QLatin1String(""), this, &MIFrameStackModel::handleThreadInfo);
+    session()->addCommand(ThreadInfo, QString(), this, &MIFrameStackModel::handleThreadInfo);
 }
 
 void MIFrameStackModel::handleThreadInfo(const ResultRecord& r)
 {
     const Value& threads = r[QStringLiteral("threads")];
 
-    QList<FrameStackModel::ThreadItem> threadsList;
+    QVector<FrameStackModel::ThreadItem> threadsList;
+    threadsList.reserve(threads.size());
     for (int i = 0; i!= threads.size(); ++i) {
         const auto &threadMI = threads[i];
         FrameStackModel::ThreadItem threadItem;
@@ -113,7 +114,8 @@ struct FrameListHandler : public MICommandHandler
     {
         const Value& stack = r[QStringLiteral("stack")];
         int first = stack[0][QStringLiteral("level")].toInt();
-        QList<KDevelop::FrameStackModel::FrameItem> frames;
+        QVector<KDevelop::FrameStackModel::FrameItem> frames;
+        frames.reserve(stack.size());
         for (int i = 0; i< stack.size(); ++i) {
             const Value& frame = stack[i];
             KDevelop::FrameStackModel::FrameItem f;
