@@ -103,19 +103,37 @@ void KDevDocumentView::mousePressEvent( QMouseEvent * event )
     QModelIndex proxyIndex = indexAt( event->pos() );
     QModelIndex index = m_proxy->mapToSource( proxyIndex );
 
-    if (event->button() == Qt::LeftButton && event->modifiers() == Qt::NoModifier) {
-        if (proxyIndex.parent().isValid()) {
-            // this is a document item
-            KDevelop::IDocumentController* dc = m_plugin->core()->documentController();
-            QUrl documentUrl = static_cast<KDevDocumentItem*>(m_documentModel->itemFromIndex(index))->fileItem()->url();
-            if (dc->documentForUrl(documentUrl) != dc->activeDocument()) {
-                dc->openDocument(documentUrl);
+    if (event->modifiers() == Qt::NoModifier) {
+        const bool actionOpen = event->button() == Qt::LeftButton;
+        const bool actionClose = event->button() == Qt::MidButton;
+        const bool action = actionOpen || actionClose;
+
+        if (action) {
+            if (proxyIndex.parent().isValid()) {
+                // this is a document item
+                KDevelop::IDocumentController* dc = m_plugin->core()->documentController();
+                QUrl documentUrl = static_cast<KDevDocumentItem*>(m_documentModel->itemFromIndex(index))->fileItem()->url();
+                KDevelop::IDocument *doc = dc->documentForUrl(documentUrl);
+
+                // Try to open a document by url.
+                if (actionOpen) {
+                    if (doc != dc->activeDocument()) {
+                        dc->openDocument(documentUrl);
+                        return;
+                    }
+                }
+                // Try to close a document.
+                else if (actionClose) {
+                    if (doc) {
+                        doc->close();
+                        return;
+                    }
+                }
+            } else if (actionOpen) {
+                // this is a folder item
+                setExpanded(proxyIndex, !isExpanded(proxyIndex));
                 return;
             }
-        } else {
-            // this is a folder item
-            setExpanded(proxyIndex, !isExpanded(proxyIndex));
-            return;
         }
     }
 
@@ -181,7 +199,7 @@ void KDevDocumentView::contextMenuEvent( QContextMenuEvent * event )
 
     if (!m_selectedDocs.isEmpty())
     {
-        QMenu* ctxMenu = new QMenu(this);
+        auto* ctxMenu = new QMenu(this);
 
         KDevelop::FileContext context(m_selectedDocs);
         const QList<KDevelop::ContextMenuExtension> extensions =
@@ -229,8 +247,7 @@ void KDevDocumentView::appendActions(QMenu* menu, const QList<QAction*>& actions
 bool KDevDocumentView::selectedDocHasChanges()
 {
     KDevelop::IDocumentController* dc = m_plugin->core()->documentController();
-    foreach(const QUrl& url, m_selectedDocs)
-    {
+    for (const QUrl& url : qAsConst(m_selectedDocs)) {
         KDevelop::IDocument* doc = dc->documentForUrl(url);
         if (!doc) continue;
         if (doc->state() != KDevelop::IDocument::Clean)
@@ -321,8 +338,10 @@ void KDevDocumentView::updateCategoryItem( KDevCategoryItem *item )
 
 void KDevDocumentView::updateProjectPaths()
 {
-    foreach ( KDevCategoryItem *it, m_documentModel->categoryList() )
+    const auto categoryList = m_documentModel->categoryList();
+    for (KDevCategoryItem* it : categoryList) {
         updateCategoryItem( it );
+    }
 }
 
 void KDevDocumentView::contentChanged( KDevelop::IDocument* )
