@@ -71,12 +71,12 @@ void OutputPagePrivate::updateRanges(QSpinBox* line, QSpinBox* column, bool enab
 
 void OutputPagePrivate::updateFileRange(const QString& field)
 {
-    if (!outputFiles.contains(field))
-    {
+    const auto outputFileIt = outputFiles.constFind(field);
+    if (outputFileIt == outputFiles.constEnd()) {
         return;
     }
 
-    QString url = outputFiles[field]->url().toLocalFile();
+    const QString url = (*outputFileIt)->url().toLocalFile();
     QFileInfo info(url);
 
     updateRanges(outputLines[field], outputColumns[field], info.exists() && !info.isDir());
@@ -177,19 +177,20 @@ void OutputPage::prepareForm(const SourceFileTemplate& fileTemplate)
     d->outputColumns.clear();
     d->labels.clear();
 
-    const int outputFilesCount = fileTemplate.outputFiles().count();
+    const auto outputFiles = fileTemplate.outputFiles();
+
+    const int outputFilesCount = outputFiles.count();
     d->output->urlGroupBox->setTitle(i18np("Output file", "Output files", outputFilesCount));
     d->output->positionGroupBox->setTitle(i18np("Location within existing file", "Location within existing files", outputFilesCount));
 
-    foreach (const SourceFileTemplate::OutputFile& file, fileTemplate.outputFiles())
-    {
+    for (const SourceFileTemplate::OutputFile& file : outputFiles) {
         const QString id = file.identifier;
         d->fileIdentifiers << id;
 
         const QString fileLabelText = i18n("%1:", file.label);
         QLabel* label = new QLabel(fileLabelText, this);
         d->labels << label;
-        KUrlRequester* requester = new KUrlRequester(this);
+        auto* requester = new KUrlRequester(this);
         requester->setMode( KFile::File | KFile::LocalOnly );
 
         connect(requester, &KUrlRequester::textChanged, this, [this, id] () { d->updateFileRange(id); });
@@ -199,7 +200,7 @@ void OutputPage::prepareForm(const SourceFileTemplate& fileTemplate)
 
         label = new QLabel(fileLabelText, this);
         d->labels << label;
-        QHBoxLayout* layout = new QHBoxLayout;
+        auto* layout = new QHBoxLayout;
 
         auto line = new QSpinBox(this);
         line->setPrefix(i18n("Line: "));
@@ -232,8 +233,8 @@ void OutputPage::loadFileTemplate(const SourceFileTemplate& fileTemplate,
     bool lower = codegenGroup.readEntry( "LowerCaseFilenames", true );
     d->output->lowerFilenameCheckBox->setChecked(lower);
 
-    foreach (const SourceFileTemplate::OutputFile& file, fileTemplate.outputFiles())
-    {
+    const auto outputFiles = fileTemplate.outputFiles();
+    for (const SourceFileTemplate::OutputFile& file : outputFiles) {
         d->fileIdentifiers << file.identifier;
 
         QUrl url = baseUrl.resolved(QUrl(renderer->render(file.outputName)));
@@ -259,8 +260,7 @@ QHash< QString, QUrl > OutputPage::fileUrls() const
 QHash< QString, KTextEditor::Cursor > OutputPage::filePositions() const
 {
     QHash<QString, KTextEditor::Cursor> positions;
-    foreach (const QString& identifier, d->fileIdentifiers)
-    {
+    for (const QString& identifier : qAsConst(d->fileIdentifiers)) {
         positions.insert(identifier, KTextEditor::Cursor(d->outputLines[identifier]->value(), d->outputColumns[identifier]->value()));
     }
     return positions;
