@@ -29,11 +29,12 @@
 #include <vcs/vcslocation.h>
 
 #include "ui_kdeconfig.h"
+#include "filterproxysearchline.h"
 #include "kdeconfig.h"
 #include "kdeprojectsmodel.h"
 #include "kdeprojectsreader.h"
 #include <QSortFilterProxyModel>
-#include <KFilterProxySearchLine>
+
 #include <KMessageBox>
 #include <KLocalizedString>
 
@@ -44,10 +45,10 @@ KDEProviderWidget::KDEProviderWidget(QWidget* parent)
 {
     setLayout(new QVBoxLayout);
     m_projects = new QListView(this);
-    QHBoxLayout* topLayout = new QHBoxLayout;
-    KFilterProxySearchLine* filterLine = new KFilterProxySearchLine(this);
-    KDEProjectsModel* model = new KDEProjectsModel(this);
-    KDEProjectsReader* reader = new KDEProjectsReader(model, model);
+    auto* topLayout = new QHBoxLayout;
+    auto filterLine = new FilterProxySearchLine(this);
+    auto* model = new KDEProjectsModel(this);
+    auto* reader = new KDEProjectsReader(model, model);
     connect(reader, &KDEProjectsReader::downloadDone, reader, &KDEProjectsReader::deleteLater);
     connect(m_projects, &QListView::clicked, this, &KDEProviderWidget::projectIndexChanged);
 
@@ -63,14 +64,16 @@ KDEProviderWidget::KDEProviderWidget(QWidget* parent)
     layout()->addItem(topLayout);
     layout()->addWidget(m_projects);
     
-    QSortFilterProxyModel* proxyModel = new QSortFilterProxyModel(this);
+    auto* proxyModel = new QSortFilterProxyModel(this);
     proxyModel->setSourceModel(model);
     proxyModel->setDynamicSortFilter(true);
     proxyModel->sort(0);
     proxyModel->setSortCaseSensitivity(Qt::CaseInsensitive);
+    proxyModel->setFilterKeyColumn(-1);
+    proxyModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     m_projects->setModel(proxyModel);
     m_projects->setEditTriggers(QAbstractItemView::NoEditTriggers);
-    filterLine->setProxy(proxyModel);
+    filterLine->setFilterProxyModel(proxyModel);
 }
 
 VcsLocation extractLocation(const QModelIndex& pos)
@@ -95,7 +98,7 @@ VcsJob* KDEProviderWidget::createWorkingCopy(const QUrl &destinationDirectory)
         KMessageBox::error(nullptr, i18n("The Git plugin could not be loaded which is required to download a KDE project."), i18n("KDE Provider Error"));
         return nullptr;
     }
-    IBasicVersionControl* vcIface = plugin->extension<IBasicVersionControl>();
+    auto* vcIface = plugin->extension<IBasicVersionControl>();
     VcsJob* ret = vcIface->createWorkingCopy(extractLocation(pos), destinationDirectory);
     
     return ret;
