@@ -81,11 +81,11 @@ OutlineNode::OutlineNode(Declaration* decl, OutlineNode* parent)
     // TODO: properly qualified identifier for out of line function definitions
     m_cachedText = decl->identifier().toString();
     m_cachedIcon = DUChainUtils::iconForDeclaration(decl);
-    if (NamespaceAliasDeclaration* alias = dynamic_cast<NamespaceAliasDeclaration*>(decl)) {
+    if (auto* alias = dynamic_cast<NamespaceAliasDeclaration*>(decl)) {
         //e.g. C++ using namespace statement
         m_cachedText = alias->importIdentifier().toString();
     }
-    else if (ClassMemberDeclaration* member = dynamic_cast<ClassMemberDeclaration*>(decl)) {
+    else if (auto* member = dynamic_cast<ClassMemberDeclaration*>(decl)) {
         if (member->isFriend()) {
             m_cachedText = QLatin1String("friend ") + m_cachedText;
         }
@@ -102,7 +102,8 @@ OutlineNode::OutlineNode(Declaration* decl, OutlineNode* parent)
             if (DUContext* fCtx = DUChainUtils::functionContext(decl)) {
                 m_cachedText += QLatin1Char('(');
                 bool first = true;
-                foreach (Declaration* childDecl, fCtx->localDeclarations(decl->topContext())) {
+                const auto childDecls = fCtx->localDeclarations(decl->topContext());
+                for (Declaration* childDecl : childDecls) {
                     if (first) {
                         first = false;
                     } else {
@@ -196,13 +197,15 @@ std::unique_ptr<OutlineNode> OutlineNode::fromTopContext(TopDUContext* ctx)
 void OutlineNode::appendContext(DUContext* ctx, TopDUContext* top)
 {
     // qDebug() << ctx->scopeIdentifier().toString() << "context type=" << ctx->type();
-    foreach (Declaration* childDecl, ctx->localDeclarations(top)) {
+    const auto childDecls = ctx->localDeclarations(top);
+    for (Declaration* childDecl : childDecls) {
         if (childDecl) {
             m_children.emplace_back(childDecl, this);
         }
     }
     bool certainlyRequiresSorting = false;
-    foreach (DUContext* childContext, ctx->childContexts()) {
+    const auto childContexts = ctx->childContexts();
+    for (DUContext* childContext : childContexts) {
         if (childContext->owner()) {
             // if there is a onwner, this will already have been handled by the loop above
             // TODO: is this always true? With my testing so far it seems to be
@@ -237,7 +240,7 @@ void OutlineNode::appendContext(DUContext* ctx, TopDUContext* top)
                 //  | \-- method2()
                 //  \ OtherStuff
                 auto it = std::find_if(m_children.begin(), m_children.end(), [childContext](const OutlineNode& node) {
-                    if (DUContext* ctx = dynamic_cast<DUContext*>(node.duChainObject())) {
+                    if (auto* ctx = dynamic_cast<DUContext*>(node.duChainObject())) {
                         return ctx->equalScopeIdentifier(childContext);
                     }
                     return false;
@@ -282,7 +285,7 @@ void OutlineNode::sortByLocation(bool requiresSorting)
         return n1.m_declOrContext->range().start < n2.m_declOrContext->range().start;
     };
     // since most nodes will be correctly sorted we check that before calling std::sort().
-    // This saves a lot of move ctor/assingnment calls in the common case.
+    // This saves a lot of move ctor/assignment calls in the common case.
     // If we appended a context without a Declaration* we know that it will be unsorted
     // so we can pass requiresSorting = true to skip the useless std::is_sorted() call.
     // uncomment the following qDebug() lines to see whether this optimization really makes sense
