@@ -67,7 +67,7 @@ public:
     {
         Q_UNUSED(parent);
 
-        ProblemsView* v = new ProblemsView();
+        auto* v = new ProblemsView();
         v->load();
         return v;
     }
@@ -141,8 +141,9 @@ void ProblemReporterPlugin::documentActivated(KDevelop::IDocument* document)
 {
   IndexedString documentUrl(document->url());
 
-  if (m_reHighlightNeeded.contains(documentUrl)) {
-    m_reHighlightNeeded.remove(documentUrl);
+  const auto neededIt = m_reHighlightNeeded.find(documentUrl);
+  if (neededIt != m_reHighlightNeeded.end()) {
+    m_reHighlightNeeded.erase(neededIt);
     updateHighlight(documentUrl);
   }
 }
@@ -162,7 +163,8 @@ void ProblemReporterPlugin::updateHighlight(const KDevelop::IndexedString& url)
     KDevelop::ProblemModelSet* pms(core()->languageController()->problemModelSet());
     QVector<IProblem::Ptr> documentProblems;
 
-    foreach (const ModelData& modelData, pms->models()) {
+    const auto models = pms->models();
+    for (const ModelData& modelData : models) {
         documentProblems += modelData.model->problems({url});
     }
 
@@ -171,7 +173,7 @@ void ProblemReporterPlugin::updateHighlight(const KDevelop::IndexedString& url)
 
 void ProblemReporterPlugin::showModel(const QString& id)
 {
-    auto w = dynamic_cast<ProblemsView*>(core()->uiController()->findToolView(i18n("Problems"), m_factory));
+    auto w = qobject_cast<ProblemsView*>(core()->uiController()->findToolView(i18n("Problems"), m_factory));
     if (w)
       w->showModel(id);
 }
@@ -180,7 +182,7 @@ KDevelop::ContextMenuExtension ProblemReporterPlugin::contextMenuExtension(KDeve
 {
     KDevelop::ContextMenuExtension extension;
 
-    KDevelop::EditorContext* editorContext = dynamic_cast<KDevelop::EditorContext*>(context);
+    auto* editorContext = dynamic_cast<KDevelop::EditorContext*>(context);
     if (editorContext) {
         DUChainReadLocker lock(DUChain::lock(), 1000);
         if (!lock.locked()) {
@@ -193,14 +195,17 @@ KDevelop::ContextMenuExtension ProblemReporterPlugin::contextMenuExtension(KDeve
 
         TopDUContext* top = DUChainUtils::standardContextForUrl(editorContext->url());
         if (top) {
-            foreach (KDevelop::ProblemPointer problem, top->problems()) {
+            const auto problems = top->problems();
+            for (auto& problem : problems) {
                 if (problem->range().contains(
                         top->transformToLocalRevision(KTextEditor::Cursor(editorContext->position())))) {
                     KDevelop::IAssistant::Ptr solution = problem->solutionAssistant();
                     if (solution) {
                         title = solution->title();
-                        foreach (KDevelop::IAssistantAction::Ptr action, solution->actions())
+                        const auto solutionActions = solution->actions();
+                        for (auto& action : solutionActions) {
                             actions << action->toQAction(parent);
+                        }
                     }
                 }
             }
@@ -214,9 +219,10 @@ KDevelop::ContextMenuExtension ProblemReporterPlugin::contextMenuExtension(KDeve
                 text = i18n("Solve: %1", KDevelop::htmlToPlainText(title));
             }
 
-            QMenu* menu = new QMenu(text, parent);
-            foreach (QAction* action, actions)
+            auto* menu = new QMenu(text, parent);
+            for (QAction* action : qAsConst(actions)) {
                 menu->addAction(action);
+            }
 
             extension.addAction(ContextMenuExtension::ExtensionGroup, menu->menuAction());
         }
@@ -226,7 +232,8 @@ KDevelop::ContextMenuExtension ProblemReporterPlugin::contextMenuExtension(KDeve
 
 void ProblemReporterPlugin::updateOpenedDocumentsHighlight()
 {
-    foreach(auto document, core()->documentController()->openDocuments()) {
+    const auto openDocuments = core()->documentController()->openDocuments();
+    for (auto* document : openDocuments) {
         // Skip non-text documents.
         // This also fixes crash caused by calling updateOpenedDocumentsHighlight() method without
         // any opened documents. In this case documentController()->openDocuments() returns single
@@ -245,5 +252,3 @@ void ProblemReporterPlugin::updateOpenedDocumentsHighlight()
 }
 
 #include "problemreporterplugin.moc"
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
