@@ -53,7 +53,6 @@
 #include <interfaces/contextmenuextension.h>
 #include <interfaces/iselectioncontroller.h>
 #include <serialization/indexedstring.h>
-#include <qtcompat_p.h>
 
 #include "projectmanagerview.h"
 #include "debug.h"
@@ -67,7 +66,7 @@ namespace {
 
 QAction* createSeparatorAction()
 {
-    QAction* separator = new QAction(nullptr);
+    auto* separator = new QAction(nullptr);
     separator->setSeparator(true);
     return separator;
 }
@@ -93,7 +92,7 @@ QMimeData* createClipboardMimeData(const bool cut)
         return nullptr;
     }
 
-    QMimeData* mimeData = new QMimeData;
+    auto* mimeData = new QMimeData;
     KIO::setClipboardDataCut(mimeData, cut);
     KUrlMimeData::setUrls(urls, mostLocalUrls, mimeData);
     return mimeData;
@@ -241,7 +240,7 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension(KDevelop::Co
     if( context->type() != KDevelop::Context::ProjectItemContext )
         return IPlugin::contextMenuExtension(context, parent);
 
-    KDevelop::ProjectItemContext* ctx = static_cast<KDevelop::ProjectItemContext*>(context);
+    auto* ctx = static_cast<KDevelop::ProjectItemContext*>(context);
     const QList<KDevelop::ProjectBaseItem*> items = ctx->items();
 
     d->ctxProjectItemList.clear();
@@ -382,8 +381,7 @@ void ProjectManagerViewPlugin::closeProjects()
 {
     QList<KDevelop::IProject*> projectsToClose;
     ProjectModel* model = ICore::self()->projectController()->projectModel();
-    foreach( const QModelIndex& index, d->ctxProjectItemList )
-    {
+    for (const QModelIndex& index : qAsConst(d->ctxProjectItemList)) {
         KDevelop::ProjectBaseItem* item = model->itemFromIndex(index);
         if( !projectsToClose.contains( item->project() ) )
         {
@@ -391,8 +389,7 @@ void ProjectManagerViewPlugin::closeProjects()
         }
     }
     d->ctxProjectItemList.clear();
-    foreach( KDevelop::IProject* proj, projectsToClose )
-    {
+    for (KDevelop::IProject* proj : qAsConst(projectsToClose)) {
         core()->projectController()->closeProject( proj );
     }
 }
@@ -447,7 +444,7 @@ QList<ProjectBaseItem*> ProjectManagerViewPlugin::collectItems()
 
     } else
     {
-        KDevelop::ProjectItemContext* ctx = static_cast<KDevelop::ProjectItemContext*>(ICore::self()->selectionController()->currentSelection());
+        auto* ctx = static_cast<KDevelop::ProjectItemContext*>(ICore::self()->selectionController()->currentSelection());
         items = ctx->items();
     }
 
@@ -456,7 +453,7 @@ QList<ProjectBaseItem*> ProjectManagerViewPlugin::collectItems()
 
 void ProjectManagerViewPlugin::runBuilderJob( BuilderJob::BuildType type, const QList<ProjectBaseItem*>& items )
 {
-    BuilderJob* builder = new BuilderJob;
+    auto* builder = new BuilderJob;
     builder->addItems( type, items );
     builder->updateJobName();
     ICore::self()->uiController()->registerStatus(new JobStatus(builder));
@@ -490,16 +487,16 @@ void ProjectManagerViewPlugin::buildProjectItems()
 
 void ProjectManagerViewPlugin::addItemsFromContextMenuToBuildset( )
 {
-    foreach( KDevelop::ProjectBaseItem* item, itemsFromIndexes( d->ctxProjectItemList ))
-    {
+    const auto items = itemsFromIndexes(d->ctxProjectItemList);
+    for (KDevelop::ProjectBaseItem* item : items) {
         ICore::self()->projectController()->buildSetModel()->addProjectItem( item );
     }
 }
 
 void ProjectManagerViewPlugin::runTargetsFromContextMenu( )
 {
-    foreach( KDevelop::ProjectBaseItem* item, itemsFromIndexes( d->ctxProjectItemList ))
-    {
+    const auto items = itemsFromIndexes(d->ctxProjectItemList);
+    for (KDevelop::ProjectBaseItem* item : items) {
         KDevelop::ProjectExecutableTargetItem* t=item->executable();
         if(t)
         {
@@ -520,12 +517,13 @@ void ProjectManagerViewPlugin::projectConfiguration( )
 void ProjectManagerViewPlugin::reloadFromContextMenu( )
 {
     QList< KDevelop::ProjectFolderItem* > folders;
-    foreach( KDevelop::ProjectBaseItem* item, itemsFromIndexes( d->ctxProjectItemList ) )
-    {
+    const auto items = itemsFromIndexes(d->ctxProjectItemList);
+    for (KDevelop::ProjectBaseItem* item : items) {
         if ( item->folder() ) {
             // since reloading should be recursive, only pass the upper-most items
             bool found = false;
-            foreach ( KDevelop::ProjectFolderItem* existing, folders ) {
+            const auto currentFolders = folders;
+            for (KDevelop::ProjectFolderItem* existing : currentFolders) {
                 if ( existing->path().isParentOf(item->folder()->path()) ) {
                     // simply skip this child
                     found = true;
@@ -541,15 +539,15 @@ void ProjectManagerViewPlugin::reloadFromContextMenu( )
             }
         }
     }
-    foreach( KDevelop::ProjectFolderItem* folder, folders ) {
+    for (KDevelop::ProjectFolderItem* folder : qAsConst(folders)) {
         folder->project()->projectFileManager()->reload(folder);
     }
 }
 
 void ProjectManagerViewPlugin::createFolderFromContextMenu( )
 {
-    foreach( KDevelop::ProjectBaseItem* item, itemsFromIndexes( d->ctxProjectItemList ))
-    {
+    const auto items = itemsFromIndexes(d->ctxProjectItemList);
+    for (KDevelop::ProjectBaseItem* item : items) {
         if ( item->folder() ) {
             QWidget* window(ICore::self()->uiController()->activeMainWindow()->window());
             QString name = QInputDialog::getText ( window,
@@ -579,8 +577,7 @@ void ProjectManagerViewPlugin::removeItems(const QList< ProjectBaseItem* >& item
     Path lastFolder;
     QHash< IProjectFileManager*, QList<KDevelop::ProjectBaseItem*> > filteredItems;
     QStringList itemPaths;
-    foreach( KDevelop::ProjectBaseItem* item, sortedItems )
-    {
+    for (KDevelop::ProjectBaseItem* item : qAsConst(sortedItems)) {
         if (item->isProjectRoot()) {
             continue;
         } else if (item->folder() || item->file()) {
@@ -703,12 +700,12 @@ ProjectFileItem* createFile(const ProjectFolderItem* item)
 
 void ProjectManagerViewPlugin::createFileFromContextMenu( )
 {
-    foreach( KDevelop::ProjectBaseItem* item, itemsFromIndexes( d->ctxProjectItemList ) )
-    {
+    const auto items = itemsFromIndexes(d->ctxProjectItemList);
+    for (KDevelop::ProjectBaseItem* item : items) {
         if ( item->folder() ) {
             createFile(item->folder());
         } else if ( item->target() ) {
-            ProjectFolderItem* folder=dynamic_cast<ProjectFolderItem*>(item->parent());
+            auto* folder=dynamic_cast<ProjectFolderItem*>(item->parent());
             if(folder)
             {
                 ProjectFileItem* f=createFile(folder);
@@ -746,7 +743,7 @@ static void selectItemsByPaths(ProjectManagerView* view, const Path::List& paths
 
 void ProjectManagerViewPlugin::pasteFromContextMenu()
 {
-    KDevelop::ProjectItemContext* ctx = static_cast<KDevelop::ProjectItemContext*>(ICore::self()->selectionController()->currentSelection());
+    auto* ctx = static_cast<KDevelop::ProjectItemContext*>(ICore::self()->selectionController()->currentSelection());
     if (ctx->items().count() != 1) {
         return; //do nothing if multiple or none items are selected
     }
@@ -768,7 +765,7 @@ void ProjectManagerViewPlugin::pasteFromContextMenu()
         isCut ? CutCopyPasteHelpers::Operation::CUT : CutCopyPasteHelpers::Operation::COPY);
 
     // Select new items in the project manager view
-    ProjectManagerViewItemContext* itemCtx = dynamic_cast<ProjectManagerViewItemContext*>(ICore::self()->selectionController()->currentSelection());
+    auto* itemCtx = dynamic_cast<ProjectManagerViewItemContext*>(ICore::self()->selectionController()->currentSelection());
     if (itemCtx) {
         Path::List finalPathsList;
         for (const auto& task : tasks) {
