@@ -78,9 +78,12 @@ OutputWidget* StandardOutputViewTest::toolViewPointer(const QString& toolViewTit
 {
     const QList< Sublime::View* > views = m_controller->activeArea()->toolViews();
     for (Sublime::View* view : views) {
-        Sublime::ToolDocument *doc = dynamic_cast<Sublime::ToolDocument*>(view->document());
+        auto* doc = qobject_cast<Sublime::ToolDocument*>(view->document());
         if(doc) {
             if(doc->title() == toolViewTitle && view->hasWidget()) {
+                // cannot use qobject_cast here, test code currently slighty fragile due to
+                // duplicated compilation of OutputWidget, here & loaded plugin
+                // cmp. comment in CMakeLists.txt
                 return dynamic_cast<OutputWidget*>(view->widget());
             }
         }
@@ -195,8 +198,8 @@ void StandardOutputViewTest::testSetModelAndDelegate()
     m_stdOutputView->setModel(outputId[0], model);
     m_stdOutputView->setDelegate(outputId[0], delegate);
 
-    QCOMPARE(outputWidget->m_views.value(outputId[0])->model(), model);
-    QCOMPARE(outputWidget->m_views.value(outputId[0])->itemDelegate(), delegate);
+    QCOMPARE(outputWidget->m_views.value(outputId[0]).view->model(), model);
+    QCOMPARE(outputWidget->m_views.value(outputId[0]).view->itemDelegate(), delegate);
 
     QVERIFY(model->parent()); // they have a parent (the outputdata), so parent() != 0x0
     QVERIFY(delegate->parent());
